@@ -201,12 +201,12 @@ repository <https://gitlab.com/ae-group/kivy_lisz>`__ .
 from abc import abstractmethod, ABC
 from typing import Any, Dict, Optional, Sequence, Tuple, Union
 
-from ae.core import stack_vars, try_eval                                        # type: ignore
+from ae.inspector import stack_vars, try_eval                                   # type: ignore
 from ae.i18n import default_language, get_f_string, translation                 # type: ignore
 from ae.gui_app import FLOW_KEY_SEP, id_of_flow, MainAppBase                    # type: ignore
 
 
-__version__ = '0.0.1'
+__version__ = '0.0.3'
 
 
 IGNORED_HELP_FLOWS = (id_of_flow('close', 'flow_popup'), )  #: tuple of flow ids never search/show help text for
